( cd usr/lib ; rm -rf libgtkhtml-2.so.0 )
( cd usr/lib ; ln -sf libgtkhtml-2.so.0.0.0 libgtkhtml-2.so.0 )
( cd usr/lib ; rm -rf libgtkhtml-2.so )
( cd usr/lib ; ln -sf libgtkhtml-2.so.0.0.0 libgtkhtml-2.so )
