/*
   Copyright (C) 2000 CodeFactory AB
   Copyright (C) 2000 Jonas Borgström <jonas@codefactory.se>
   Copyright (C) 2000 Anders Carlsson <andersca@codefactory.se>
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
   
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

/* CSS 1 & 2 properties */

HTML_ATOM(BACKGROUND, "background")
HTML_ATOM(BACKGROUND_ATTACHMENT, "background-attachment")
HTML_ATOM(BACKGROUND_COLOR, "background-color")
HTML_ATOM(BACKGROUND_IMAGE, "background-image")
HTML_ATOM(BACKGROUND_POSITION, "background-position")
HTML_ATOM(BACKGROUND_REPEAT, "background-repeat")
HTML_ATOM(BORDER, "border")
HTML_ATOM(BORDER_BOTTOM, "border-bottom")
HTML_ATOM(BORDER_BOTTOM_COLOR, "border-bottom-color")
HTML_ATOM(BORDER_BOTTOM_STYLE, "border-bottom-style")
HTML_ATOM(BORDER_BOTTOM_WIDTH, "border-bottom-width")
HTML_ATOM(BORDER_COLOR, "border-color")
HTML_ATOM(BORDER_COLLAPSE, "border-collapse")
HTML_ATOM(BORDER_LEFT, "border-left")
HTML_ATOM(BORDER_LEFT_COLOR, "border-left-color")
HTML_ATOM(BORDER_LEFT_STYLE, "border-left-style")
HTML_ATOM(BORDER_LEFT_WIDTH, "border-left-width")
HTML_ATOM(BORDER_RIGHT, "border-right")
HTML_ATOM(BORDER_RIGHT_COLOR, "border-right-color")
HTML_ATOM(BORDER_RIGHT_STYLE, "border-right-style")
HTML_ATOM(BORDER_RIGHT_WIDTH, "border-right-width")
HTML_ATOM(BORDER_SPACING, "border-spacing")
HTML_ATOM(BORDER_STYLE, "border-style")
HTML_ATOM(BORDER_TOP, "border-top")
HTML_ATOM(BORDER_TOP_COLOR, "border-top-color")
HTML_ATOM(BORDER_TOP_STYLE, "border-top-style")
HTML_ATOM(BORDER_TOP_WIDTH, "border-top-width")
HTML_ATOM(BORDER_WIDTH, "border-width")
HTML_ATOM(BOTTOM, "bottom")
HTML_ATOM(CAPTION_SIDE, "caption-side")
HTML_ATOM(CLEAR, "clear")
HTML_ATOM(CLIP, "clip")
HTML_ATOM(COLOR, "color")
HTML_ATOM(CONTENT, "content")
HTML_ATOM(COUNTER_INCREMENT, "counter-increment")
HTML_ATOM(COUNTER_RESET, "counter-reset")
HTML_ATOM(CURSOR, "cursor")
HTML_ATOM(DIRECTION, "direction")
HTML_ATOM(DISPLAY, "display")
HTML_ATOM(EMPTY_CELL, "empty-cell")
HTML_ATOM(FLOAT, "float")
HTML_ATOM(FONT, "font")
HTML_ATOM(FONT_FAMILY, "font-family")
HTML_ATOM(FONT_SIZE, "font-size")
HTML_ATOM(FONT_SIZE_ADJUST, "font-size-adjust")
HTML_ATOM(FONT_STRETCH, "font-stretch")
HTML_ATOM(FONT_STYLE, "font-style")
HTML_ATOM(FONT_VARIANT, "font-variant")
HTML_ATOM(FONT_WEIGHT, "font-weight")
HTML_ATOM(HEIGHT, "height")
HTML_ATOM(LEFT, "left")
HTML_ATOM(LETTER_SPACING, "letter-spacing")
HTML_ATOM(LINE_HEIGHT, "line-height")
HTML_ATOM(LINE_STYLE, "list-style")
HTML_ATOM(LIST_STYLE_TYPE, "list-style-type")
HTML_ATOM(LIST_STYLE_IMAGE, "list-style-image")
HTML_ATOM(LIST_STYLE_POSITION, "list-style-position")
HTML_ATOM(MARGIN, "margin")
HTML_ATOM(MARGIN_BOTTOM, "margin-bottom")
HTML_ATOM(MARGIN_LEFT, "margin-left")
HTML_ATOM(MARGIN_TOP, "margin-top")
HTML_ATOM(MARGIN_RIGHT, "margin-right")
HTML_ATOM(MARKER_OFFSET, "marker-offset")
HTML_ATOM(MARKS, "marks")
HTML_ATOM(MAX_HEIGHT, "max-height")
HTML_ATOM(MAX_WIDTH, "max-width")
HTML_ATOM(MIN_HEIGHT, "min-height")
HTML_ATOM(MIN_WIDTH, "min-width")
HTML_ATOM(ORPHANS, "orphans")
HTML_ATOM(OUTLINE, "outline")
HTML_ATOM(OUTLINE_COLOR, "outline-color")
HTML_ATOM(OUTLINE_STYLE, "outline-style")
HTML_ATOM(OUTLINE_WIDTH, "outline-width")
HTML_ATOM(INVERT, "invert")
HTML_ATOM(OVERFLOW, "overflow")
HTML_ATOM(PADDING, "padding")
HTML_ATOM(PADDING_BOTTOM, "padding-bottom")
HTML_ATOM(PADDING_LEFT, "padding-left")
HTML_ATOM(PADDING_TOP, "padding-top")
HTML_ATOM(PADDING_RIGHT, "padding-right")
HTML_ATOM(PAGE, "page")
HTML_ATOM(PAGE_BREAK_AFTER, "page-break-after")
HTML_ATOM(PAGE_BREAK_BEFORE, "page-break-before")
HTML_ATOM(PAGE_INSIDE, "page-inside")
HTML_ATOM(POSITION, "position")
HTML_ATOM(QUOTES, "quotes")
HTML_ATOM(RIGHT, "right")
HTML_ATOM(SIZE, "size")
HTML_ATOM(TABLE_LAYOUT, "table-layout")
HTML_ATOM(TEXT_ALIGN, "text-align")
HTML_ATOM(TEXT_DECORATION, "text-decoration")
HTML_ATOM(TEXT_INDENT, "text-indent")
HTML_ATOM(TEXT_SHADOW, "text-shadow")
HTML_ATOM(TEXT_TRANSFORM, "text-transform")
HTML_ATOM(TOP, "top")
HTML_ATOM(UNICODE_BIDI, "unicode-bidi")
HTML_ATOM(VERTICAL_ALIGN, "vertical-align")
HTML_ATOM(VISIBILITY, "visibility")
HTML_ATOM(WIDOWS, "widows")
HTML_ATOM(WIDTH, "width")
HTML_ATOM(WHITE_SPACE, "white-space")
HTML_ATOM(WORD_SPACING, "word-spacing")
HTML_ATOM(Z_INDEX, "z-index")

/* display: values */
HTML_ATOM(INLINE, "inline")
HTML_ATOM(BLOCK, "block")
HTML_ATOM(LIST_ITEM, "list-item")
HTML_ATOM(RUN_IN, "run-in")
HTML_ATOM(COMPACT, "compact")
HTML_ATOM(MARKER, "marker")
HTML_ATOM(TABLE, "table")
HTML_ATOM(INLINE_TABLE, "inline-table")
HTML_ATOM(TABLE_ROW_GROUP, "table-row-group")
HTML_ATOM(TABLE_HEADER_GROUP, "table-header-group")
HTML_ATOM(TABLE_FOOTER_GROUP, "table-footer-group")
HTML_ATOM(TABLE_ROW, "table-row")
HTML_ATOM(TABLE_COLUMN, "table-column")
HTML_ATOM(TABLE_COLUMN_GROUP, "table-column-group")
HTML_ATOM(TABLE_CELL, "table-cell")
HTML_ATOM(TABLE_CAPTION, "table-caption")
HTML_ATOM(CAPTION, "caption")
HTML_ATOM(NONE, "none")

/* visibility: values */
HTML_ATOM(VISIBLE, "visible")
HTML_ATOM(HIDDEN, "hidden")
HTML_ATOM(COLLAPSE, "collapse")

/* overflow: values */
HTML_ATOM(SCROLL, "scroll")
HTML_ATOM(AUTO, "auto")

/* text-transform: values */
HTML_ATOM(UPPERCASE, "uppercase")
HTML_ATOM(LOWERCASE, "lowercase")
HTML_ATOM(CAPITALIZE, "capitalize")

/* white-space: values */
HTML_ATOM(NORMAL, "normal")
HTML_ATOM(PRE, "pre")
HTML_ATOM(NOWRAP, "nowrap")

/* clear: values */
HTML_ATOM(BOTH, "both")

/* position: values */
HTML_ATOM(STATIC, "static")
HTML_ATOM(FIXED, "fixed")
HTML_ATOM(RELATIVE, "relative")
HTML_ATOM(ABSOLUTE, "absolute")

/* font-stretch: values */
HTML_ATOM(ULTRA_CONDENSED, "ultra-condensed")
HTML_ATOM(EXTRA_CONDENSED, "extra-condensed")
HTML_ATOM(CONDENSED, "condensed")
HTML_ATOM(SEMI_CONDENSED, "semi-condensed")
HTML_ATOM(SEMI_EXPANDED, "semi-expanded")
HTML_ATOM(EXPANDED, "expanded")
HTML_ATOM(EXTRA_EXPANDED, "extra-expanded")
HTML_ATOM(ULTRA_EXPANDED, "ultra-expanded")

/* font-style: valyues */
HTML_ATOM(ITALIC, "italic")
HTML_ATOM(OBLIQUE, "oblique")

/* font-weight: values */
HTML_ATOM(BOLD, "bold")
HTML_ATOM(BOLDER, "bolder")
HTML_ATOM(LIGHTER, "lighter")

/* font-size: values */
HTML_ATOM(XX_SMALL, "xx-small")
HTML_ATOM(X_SMALL, "x-small")
HTML_ATOM(SMALL, "small")
HTML_ATOM(MEDIUM, "medium")
HTML_ATOM(LARGE, "large")
HTML_ATOM(X_LARGE, "x-large")
HTML_ATOM(XX_LARGE, "xx-large")
HTML_ATOM(LARGER, "larger")
HTML_ATOM(SMALLER, "smaller")

/* font-variant: values */
HTML_ATOM(SMALL_CAPS, "small-caps")

/* text-decoration: values */
HTML_ATOM(UNDERLINE, "underline")
HTML_ATOM(OVERLINE, "overline")
HTML_ATOM(LINE_THROUGH, "line-through")
HTML_ATOM(BLINK, "blink")

/* text-align: values */
HTML_ATOM(CENTER, "center")
HTML_ATOM(JUSTIFY, "justify")

/* vertical-align: values */
HTML_ATOM(BASELINE, "baseline")
HTML_ATOM(MIDDLE, "middle")
HTML_ATOM(SUB, "sub")
HTML_ATOM(SUPER, "super")
HTML_ATOM(TEXT_TOP, "text-top")
HTML_ATOM(TEXT_BOTTOM, "text-bottom")

/* border-style: values */
HTML_ATOM(DASHED, "dashed")
HTML_ATOM(DOTTED, "dotted")
HTML_ATOM(DOUBLE, "double")
HTML_ATOM(SOLID, "solid")
HTML_ATOM(RIDGE, "ridge")
HTML_ATOM(GROOVE, "groove")
HTML_ATOM(INSET, "inset")
HTML_ATOM(OUTSET, "outset")

/* border-width: values */
HTML_ATOM(THIN, "thin")
HTML_ATOM(THICK, "thick")

/* list-item-style: values */
HTML_ATOM(DISC, "disc")
HTML_ATOM(CIRCLE, "circle")
HTML_ATOM(SQUARE, "square")
HTML_ATOM(DECIMAL, "decimal")
HTML_ATOM(DECIMAL_LEADING_ZERO, "decimal-leading-zero")
HTML_ATOM(LOWER_ROMAN, "lower-roman")
HTML_ATOM(UPPER_ROMAN, "upper-roman")
HTML_ATOM(LOWER_GREEK, "lower-greek")
HTML_ATOM(LOWER_ALPHA, "lower-alpha")
HTML_ATOM(LOWER_LATIN, "lower-latin")
HTML_ATOM(UPPER_ALPHA, "upper-alpha")
HTML_ATOM(UPPER_LATIN, "upper-latin")
HTML_ATOM(HEBREW, "hebrew")
HTML_ATOM(ARMENIAN, "armenian")
HTML_ATOM(GEORGIAN, "georgian")
HTML_ATOM(CJK_IDEOGRAPHIC, "cjk-ideographic")
HTML_ATOM(HIRAGANA, "hiragana")
HTML_ATOM(KATAKANA, "katakana")
HTML_ATOM(HIRAGANA_IROHA, "hiragana-iroha")
HTML_ATOM(KATAKANA_IROHA, "katakana-iroha")

/* list-item-style: values */
HTML_ATOM(REPEAT, "repeat")
HTML_ATOM(REPEAT_X, "repeat-x")
HTML_ATOM(REPEAT_Y, "repeat-y")
HTML_ATOM(NO_REPEAT, "no-repeat")
HTML_ATOM(SCALE, "scale")

/* css file things */
HTML_ATOM(IMPORT, "import")
HTML_ATOM(MEDIA, "media")
HTML_ATOM(FONT_FACE, "font-face")
HTML_ATOM(CHARSET, "charset")
HTML_ATOM(IMPORTANT, "important")
HTML_ATOM(URL, "url")
HTML_ATOM(INHERIT, "inherit")

/* direction: values */
HTML_ATOM(LTR, "ltr")
HTML_ATOM(RTL, "rtl")

/* unicode-bidi: values */
HTML_ATOM(BIDI_OVERRIDE, "bidi-override")
HTML_ATOM(EMBED, "embed")

/* cursor: values */
HTML_ATOM(CROSSHAIR, "crosshair")
HTML_ATOM(DEFAULT, "default")
HTML_ATOM(POINTER, "pointer")
HTML_ATOM(MOVE, "move")
HTML_ATOM(E_RESIZE, "e-resize")
HTML_ATOM(NE_RESIZE, "ne-resize")
HTML_ATOM(NW_RESIZE, "nw-resize")
HTML_ATOM(N_RESIZE, "n-resize")
HTML_ATOM(SE_RESIZE, "se-resize")
HTML_ATOM(SW_RESIZE, "sw-resize")
HTML_ATOM(S_RESIZE, "s-resize")
HTML_ATOM(W_RESIZE, "w-resize")
HTML_ATOM(TEXT, "text")
HTML_ATOM(WAIT, "wait")
HTML_ATOM(HELP, "help")

/* Pseudo selector types */
HTML_ATOM(HOVER, "hover")
HTML_ATOM(ACTIVE, "active")
HTML_ATOM(FOCUS, "focus")
HTML_ATOM(BEFORE, "before")
HTML_ATOM(AFTER, "after")
HTML_ATOM(LINK, "link")
HTML_ATOM(FIRST_CHILD, "first-child")
	
/* font-family generic  types */
HTML_ATOM(SERIF, "serif")
HTML_ATOM(SANS_SERIF, "sans-serif")
HTML_ATOM(CURSIVE, "cursive")
HTML_ATOM(FANTASY, "fantasy")
HTML_ATOM(MONOSPACE, "monospace")

/* html elements */ 
HTML_ATOM(FORM, "form")
HTML_ATOM(TEXTAREA, "textarea")
HTML_ATOM(SELECT, "select")
HTML_ATOM(OBJECT, "object")
HTML_ATOM(INPUT, "input")
HTML_ATOM(IMG, "img")

/* input types */
HTML_ATOM(SUBMIT, "submit")
HTML_ATOM(RESET, "reset")
HTML_ATOM(PASSWORD, "password")
HTML_ATOM(CHECKBOX, "checkbox")
HTML_ATOM(RADIO, "radio")
HTML_ATOM(IMAGE, "image")
